@@ -1,16 +1,13 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#ifndef GLOBALSHORTCUTCOMMANDS_H
-#define GLOBALSHORTCUTCOMMANDS_H
+#pragma once
 
-#include "common/command.h"
 
 #include <QtContainerFwd>
 
 class QString;
+struct Command;
 
 QVector<Command> globalShortcutCommands();
 
 QString pasteAsPlainTextScript(const QString &what);
-
-#endif // GLOBALSHORTCUTCOMMANDS_H
