@@ -6,10 +6,14 @@
 #include "common/log.h"
 #include "common/timer.h"
 #include "item/itemstore.h"
+#include "item/serialize.h"
 #include "gui/clipboardbrowser.h"
 #include "gui/iconfactory.h"
 #include "gui/icons.h"
 
+#include <QDataStream>
+#include <QIODevice>
+#include <QProgressBar>
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QWidget>
@@ -24,6 +28,7 @@ ClipboardBrowserPlaceholder::ClipboardBrowserPlaceholder(
 {
     auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
+    layout->setSpacing(0);
 
     initSingleShotTimer( &m_timerExpire, 0, this, &ClipboardBrowserPlaceholder::expire );
 }
@@ -41,7 +46,7 @@ ClipboardBrowser *ClipboardBrowserPlaceholder::createBrowser()
     c->setStoreItems(m_storeItems);
     c->setMaxItemCount(m_maxItemCount);
 
-    if ( !c->loadItems() ) {
+    if ( !c->loadItems(m_data) ) {
         createLoadButton();
         return nullptr;
     }
@@ -50,6 +55,8 @@ ClipboardBrowser *ClipboardBrowserPlaceholder::createBrowser()
              this, &ClipboardBrowserPlaceholder::restartExpiring);
     connect( c.get(), &ClipboardBrowser::itemsChanged,
              this, &ClipboardBrowserPlaceholder::restartExpiring);
+    connect( c.get(), &ClipboardBrowser::filterProgressChanged,
+             this, &ClipboardBrowserPlaceholder::onFilterProgressChanged);
 
     m_browser = c.release();
 
@@ -71,7 +78,7 @@ bool ClipboardBrowserPlaceholder::setTabName(const QString &tabName)
         if ( !m_browser->setTabName(tabName) )
             return false;
         reloadBrowser();
-    } else {
+    } else if (m_storeItems) {
         unloadBrowser();
         if ( !moveItems(m_tabName, tabName) ) {
             if ( isVisible() )
@@ -200,6 +207,14 @@ void ClipboardBrowserPlaceholder::unloadBrowser()
 
     COPYQ_LOG( QString("Tab \"%1\": Unloading").arg(m_tabName) );
 
+    // Keep unsaved items in memory until expiration.
+    m_data.clear();
+    if ( !m_storeItems && m_browser->isLoaded() ) {
+        QDataStream stream(&m_data, QIODevice::WriteOnly);
+        if ( !serializeData(*m_browser->model(), &stream) )
+            m_data.clear();
+    }
+
     // WORKAROUND: This is needed on macOS, to fix refocusing correct widget later.
     m_browser->clearFocus();
 
@@ -208,6 +223,9 @@ void ClipboardBrowserPlaceholder::unloadBrowser()
     m_browser->deleteLater();
     m_browser = nullptr;
 
+    if (m_filterProgressBar)
+        m_filterProgressBar->hide();
+
     emit browserDestroyed();
 }
 
@@ -232,3 +250,23 @@ bool ClipboardBrowserPlaceholder::isEditorOpen() const
                 m_browser->isInternalEditorOpen()
                 || m_browser->isExternalEditorOpen() );
 }
+
+void ClipboardBrowserPlaceholder::onFilterProgressChanged(int percent)
+{
+    if (percent >= 100) {
+        if (m_filterProgressBar)
+            m_filterProgressBar->hide();
+        return;
+    }
+
+    if (m_filterProgressBar == nullptr) {
+        m_filterProgressBar = new QProgressBar(this);
+        m_filterProgressBar->setObjectName("ClipboardBrowserFilterProgressBar");
+        m_filterProgressBar->setContentsMargins({});
+        m_filterProgressBar->setTextVisible(false);
+        layout()->addWidget(m_filterProgressBar);
+    }
+
+    m_filterProgressBar->setValue(percent);
+    m_filterProgressBar->show();
+}
