@@ -5,7 +5,6 @@
 #include "common/client_server.h"
 #include "common/contenttype.h"
 #include "common/mimetypes.h"
-#include "common/sanitize_text_document.h"
 #include "common/textdata.h"
 #include "common/timer.h"
 #include "gui/clipboardbrowser.h"
@@ -198,6 +197,7 @@ void ItemDelegate::setItemSizes(int maxWidth, int idealWidth)
     const int margin = 2 * margins.width() + 2 * m_view->spacing();
     m_maxWidth = maxWidth - margin;
     m_idealWidth = idealWidth - margin;
+    m_fontHeight = m_view->viewport()->fontMetrics().height();
 
     for (int row = 0; static_cast<size_t>(row) < m_items.size(); ++row) {
         if (m_items[row])
@@ -226,10 +226,17 @@ void ItemDelegate::updateItemSize(const QModelIndex &index, QSize itemWidgetSize
         rowNumberSize.height()
     );
 
-    const QSize newSize = QSize(width, height);
-    if (m_items[row].size == newSize)
+    QSize newSize = QSize(width, height);
+    const QSize oldSize = m_items[row].size;
+    if (oldSize == newSize)
         return;
 
+    // Avoid small height changes to make the item positions more stable
+    if (oldSize.isValid()) {
+        const int deltaH = newSize.height() - oldSize.height();
+        if ((-m_fontHeight < deltaH && deltaH < 0) || (0 < deltaH && deltaH < m_fontHeight / 3))
+            newSize.setHeight(oldSize.height());
+    }
     m_items[row].size = newSize;
     emit sizeHintChanged(index);
 }
@@ -237,6 +244,16 @@ void ItemDelegate::updateItemSize(const QModelIndex &index, QSize itemWidgetSize
 ItemEditorWidget *ItemDelegate::createCustomEditor(
         QWidget *parent, const QModelIndex &index, const QString &format)
 {
+    // If format is empty, try to find most suitable text format to edit.
+    if ( format.isEmpty() ) {
+        const QVariantMap data = m_sharedData->itemFactory->data(index);
+        for (const auto &format2 : {mimeTextUtf8, mimeText, mimeUriList, mimeHtml}) {
+            if ( data.contains(format2) )
+                return createCustomEditor(parent, index, format2);
+        }
+        return nullptr;
+    }
+
     // Refuse editing non-text data
     if ( format != mimeItemNotes && !format.startsWith(QLatin1String("text/")) )
         return nullptr;
@@ -251,10 +268,11 @@ ItemEditorWidget *ItemDelegate::createCustomEditor(
     connect(editor, &QObject::destroyed, editorParent, &QObject::deleteLater);
 
     // Prefer editing rich text
-    if ( format == mimeText && data.contains(mimeHtml) ) {
+    if ( (format == mimeText || format == mimeTextUtf8 || format == mimeHtml)
+         && data.contains(mimeHtml) )
+    {
         const QString html = getTextData(data, mimeHtml);
         editor->setHtml(html);
-        sanitizeTextDocument(editor->document());
     } else {
         const QString text = getTextData(data, format);
         editor->setPlainText(text);
@@ -478,12 +496,7 @@ void ItemDelegate::setWidgetSelected(QWidget *ww, bool selected)
         return;
 
     ww->setProperty(propertySelectedItem, selected);
-
-    QStyle *style = m_view->style();
-    ww->setStyle(style);
-    for (auto child : ww->findChildren<QWidget *>())
-        child->setStyle(style);
-    ww->update();
+    ww->setStyleSheet(m_view->styleSheet());
 }
 
 int ItemDelegate::findWidgetRow(const QObject *obj) const
