@@ -3,7 +3,6 @@
 #include "serialize.h"
 
 #include "common/contenttype.h"
-#include "common/log.h"
 #include "common/mimetypes.h"
 
 #include <QAbstractItemModel>
@@ -16,12 +15,22 @@
 #include <QFileInfo>
 #include <QIODevice>
 #include <QList>
+#include <QLoggingCategory>
 #include <QPair>
 #include <QSaveFile>
 #include <QStringList>
 
 #include <unordered_map>
 
+constexpr const int MAX_ITEMS = 100'000;
+
+namespace {
+
+Q_DECLARE_LOGGING_CATEGORY(serializeCategory)
+Q_LOGGING_CATEGORY(serializeCategory, "copyq.serialize")
+
+} // namespace
+
 class DataFile {
 public:
     DataFile() {}
@@ -44,8 +53,7 @@ public:
     {
         QFile f(m_path);
         if ( !f.open(QIODevice::ReadOnly) ) {
-            log( QStringLiteral("Failed to read file \"%1\": %2")
-                    .arg(m_path, f.errorString()), LogError );
+            qCCritical(serializeCategory) << "Failed to read file" << m_path << ":" << f.errorString();
             return QByteArray();
         }
         return f.readAll();
@@ -84,7 +92,7 @@ bool readOrError(QDataStream *out, T *value, const char *error)
     if ( out->status() == QDataStream::Ok )
         return true;
 
-    log( QString("Corrupted data: %1").arg(error), LogError );
+    qCCritical(serializeCategory) << "Corrupted data:" << error;
     return false;
 }
 
@@ -122,7 +130,7 @@ QString decompressMime(QDataStream *out)
     const int id = QStringView(mime).mid(0, 1).toInt(&ok, 16);
 #endif
     if (!ok) {
-        log("Corrupted data: Failed to parse MIME type ID", LogError);
+        qCCritical(serializeCategory) << "Corrupted data: Failed to parse MIME type ID";
         out->setStatus(QDataStream::ReadCorruptData);
         return QString();
     }
@@ -134,7 +142,7 @@ QString decompressMime(QDataStream *out)
     if ( it != std::end(idToMime()) )
         return it->second + mime.mid(1);
 
-    log("Corrupted data: Failed to decompress MIME type", LogError);
+    qCCritical(serializeCategory) << "Corrupted data: Failed to decompress MIME type";
     out->setStatus(QDataStream::ReadCorruptData);
     return QString();
 }
@@ -175,7 +183,7 @@ bool deserializeDataV2(QDataStream *out, QVariantMap *data)
         if (compress) {
             tmpBytes = qUncompress(tmpBytes);
             if ( tmpBytes.isEmpty() ) {
-                log("Corrupted data: Failed to decompress data (v2)", LogError);
+                qCCritical(serializeCategory) << "Corrupted data: Failed to decompress data (v2)";
                 out->setStatus(QDataStream::ReadCorruptData);
                 return false;
             }
@@ -209,8 +217,8 @@ QString dataFilePath(const QByteArray &bytes, bool create = false)
             sha.mid(32, 16)
     );
     if (create && !dir.mkpath(subpath)) {
-        log( QStringLiteral("Failed to create data directory: %1")
-                .arg(dir.absoluteFilePath(subpath)), LogError );
+        qCCritical(serializeCategory) << "Failed to create data directory:"
+            << dir.absoluteFilePath(subpath);
         return QString();
     }
     return dir.absoluteFilePath(
@@ -261,9 +269,8 @@ void serializeData(QDataStream *stream, const QVariantMap &data, int itemDataThr
                     QSaveFile f(path);
                     f.setDirectWriteFallback(false);
                     if ( !f.open(QIODevice::WriteOnly) || !f.write(bytes) || !f.commit() ) {
-                        log( QStringLiteral("Failed to create data file \"%1\": %2")
-                                .arg(path, f.errorString()),
-                                LogError );
+                        qCCritical(serializeCategory) << "Failed to create data file" << path << ":"
+                            << f.errorString();
                         stream->setStatus(QDataStream::WriteFailed);
                         f.cancelWriting();
                         return;
@@ -298,7 +305,7 @@ bool deserializeData(QDataStream *stream, QVariantMap *data)
             return deserializeDataV2(stream, data);
 
         if (length < 0) {
-            log("Corrupted data: Invalid length (v1)", LogError);
+            qCCritical(serializeCategory) << "Corrupted data: Invalid length (v1)";
             stream->setStatus(QDataStream::ReadCorruptData);
             return false;
         }
@@ -317,7 +324,7 @@ bool deserializeData(QDataStream *stream, QVariantMap *data)
             if( !tmpBytes.isEmpty() ) {
                 tmpBytes = qUncompress(tmpBytes);
                 if ( tmpBytes.isEmpty() ) {
-                    log("Corrupted data: Failed to decompress data (v1)", LogError);
+                    qCCritical(serializeCategory) << "Corrupted data: Failed to decompress data (v1)";
                     stream->setStatus(QDataStream::ReadCorruptData);
                     return false;
                 }
@@ -325,7 +332,7 @@ bool deserializeData(QDataStream *stream, QVariantMap *data)
             data->insert(mime, tmpBytes);
         }
     } catch (const std::exception &e) {
-        log( QString("Data deserialization failed: %1").arg(e.what()), LogError );
+        qCCritical(serializeCategory) << "Data deserialization failed:" << e.what();
         stream->setStatus(QDataStream::ReadCorruptData);
         return false;
     }
@@ -360,20 +367,20 @@ bool serializeData(const QAbstractItemModel &model, QDataStream *stream, int ite
     return stream->status() == QDataStream::Ok;
 }
 
-bool deserializeData(QAbstractItemModel *model, QDataStream *stream, int maxItems)
+bool deserializeData(QAbstractItemModel *model, QDataStream *stream)
 {
     qint32 length;
     if ( !readOrError(stream, &length, "Failed to read length") )
         return false;
 
     if (length < 0) {
-        log("Corrupted data: Invalid length", LogError);
+        qCCritical(serializeCategory) << "Corrupted data: Invalid length";
         stream->setStatus(QDataStream::ReadCorruptData);
         return false;
     }
 
     // Limit the loaded number of items to model's maximum.
-    length = qMin(length, maxItems) - model->rowCount();
+    length = qMin(length, MAX_ITEMS) - model->rowCount();
 
     if ( length != 0 && !model->insertRows(0, length) )
         return false;
@@ -384,7 +391,7 @@ bool deserializeData(QAbstractItemModel *model, QDataStream *stream, int maxItem
             return false;
 
         if ( !model->setData(model->index(i, 0), data, contentType::data) ) {
-            log("Failed to set model data", LogError);
+            qCCritical(serializeCategory) << "Failed to set model data";
             stream->setStatus(QDataStream::ReadCorruptData);
             return false;
         }
@@ -400,11 +407,11 @@ bool serializeData(const QAbstractItemModel &model, QIODevice *file, int itemDat
     return serializeData(model, &stream, itemDataThreshold);
 }
 
-bool deserializeData(QAbstractItemModel *model, QIODevice *file, int maxItems)
+bool deserializeData(QAbstractItemModel *model, QIODevice *file)
 {
     QDataStream stream(file);
     stream.setVersion(QDataStream::Qt_4_7);
-    return deserializeData(model, &stream, maxItems);
+    return deserializeData(model, &stream);
 }
 
 bool itemDataFiles(QIODevice *file, QStringList *files)
@@ -417,7 +424,7 @@ bool itemDataFiles(QIODevice *file, QStringList *files)
         return false;
 
     if (length < 0) {
-        log("Corrupted data: Invalid length", LogError);
+        qCCritical(serializeCategory) << "Corrupted data: Invalid length";
         return false;
     }
 
