@@ -90,6 +90,7 @@ void Tests::commandPrint()
 
 void Tests::commandAbort()
 {
+    RUN("abort(); 1", "");
     RUN("eval" << "abort(); 1", "");
     RUN("eval" << "eval('abort(); print(1)'); 2", "");
     RUN("eval" << "execute('copyq', 'eval', '--', 'abort(); print(1)'); 2", "2\n");
@@ -99,7 +100,7 @@ void Tests::commandFail()
 {
     QByteArray stdoutActual;
     QByteArray stderrActual;
-    QCOMPARE( run(Args("fail"), &stdoutActual, &stderrActual), 1 );
+    QCOMPARE( run(Args("fail"), &stdoutActual, &stderrActual), 10 );
     QVERIFY2( testStderr(stderrActual), stderrActual );
     QCOMPARE( stdoutActual, QByteArray() );
 }
@@ -227,6 +228,13 @@ void Tests::commandsWriteRead()
         CommandException, "Unexpected uneven number of mimeType/data arguments");
 }
 
+void Tests::commandsReadUtf8ByDefault()
+{
+    RUN("add({[mimeText]: 'A', [mimeTextUtf8]: 'B'})", "");
+    RUN("read(mimeText, 0)", "A");
+    RUN("read(0)", "B");
+}
+
 void Tests::commandChange()
 {
     RUN("add" << "C" << "B" << "A", "");
@@ -302,31 +310,31 @@ void Tests::commandDialog()
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('text')", "TEST\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QLineEdit in :QDialog" << ":TEST" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QLineEdit<:QDialog" << ":TEST" << "ENTER", ""); }
     );
 
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('text') === undefined", "true\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QLineEdit in :QDialog" << "ESCAPE", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QLineEdit<:QDialog" << "ESCAPE", ""); }
     );
 
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('.defaultChoice', 2, 'list', [1, 2, 3])", "2\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QComboBox in :QDialog" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QComboBox<:QDialog" << "ENTER", ""); }
     );
 
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('.defaultChoice', '', 'list', [1, 2, 3])", "\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QComboBox in :QDialog" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QComboBox<:QDialog" << "ENTER", ""); }
     );
 
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('list', [0, 1, 2])", "0\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QComboBox in :QDialog" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QComboBox<:QDialog" << "ENTER", ""); }
     );
 
     // Can't focus configuration checkboxes on OS X
@@ -334,7 +342,7 @@ void Tests::commandDialog()
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('boolean', true) === true", "true\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QCheckBox in :QDialog" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QCheckBox<:QDialog" << "ENTER", ""); }
     );
 #endif
 
@@ -343,7 +351,7 @@ void Tests::commandDialog()
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('.title', 'test', 'text')", ""); },
-        [&]() { RUN(Args() << "keys" << "focus::QLineEdit in dialog_test:QDialog" << "ESCAPE", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QLineEdit<dialog_test:QDialog" << "ESCAPE", ""); }
     );
 
     RUN(Args() << "keys" << clipboardBrowserId, "");
@@ -361,13 +369,26 @@ void Tests::commandDialog()
     )";
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT + script, "DEFAULT\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QLineEdit in :QDialog" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QLineEdit<:QDialog" << "ENTER", ""); }
     );
 
     RUN(Args() << "keys" << clipboardBrowserId, "");
     runMultiple(
         [&]() { RUN(WITH_TIMEOUT "dialog('.title', 'Remove Items', '.label', 'Remove all items?') === true", "true\n"); },
-        [&]() { RUN(Args() << "keys" << "focus::QPushButton in dialog_Remove Items:QDialog" << "ENTER", ""); }
+        [&]() { RUN(Args() << "keys" << "focus::QPushButton<dialog_Remove Items:QDialog" << "ENTER", ""); }
+    );
+
+    RUN(Args() << "keys" << clipboardBrowserId, "");
+    const QByteArray script2 = R"(
+        dialog(
+            '.modal', true,
+            '.onTop', true,
+            'text', 'DEFAULT',
+        )
+    )";
+    runMultiple(
+        [&]() { RUN(WITH_TIMEOUT + script2, "DEFAULT\n"); },
+        [&]() { RUN(Args() << "keys" << "focus::QLineEdit<:QDialog" << "ENTER", ""); }
     );
 }
 
@@ -631,6 +652,10 @@ void Tests::commandCopy()
     RUN_EXPECT_ERROR_WITH_STDERR(
         "copy([{}, {}])",
         CommandException, "Expected single item");
+
+    // Test copying UTF-8 text.
+    RUN("--" << "copy({[mimeText]: '\\\\u2705', [mimeTextUtf8]: '✅'})", "true\n");
+    WAIT_FOR_CLIPBOARD2("✅", mimeTextUtf8);
 }
 
 void Tests::commandClipboard()
@@ -688,16 +713,15 @@ void Tests::commandEditItem()
     TEST( m_test->setClipboard("TEST", mimeHtml) );
     RUN("editItem" << "-1" << mimeHtml, "");
     RUN("keys" << "END" << ":LINE 1" << "F2", "");
-#ifdef Q_OS_WIN
-#   define FRAG_START "<!--StartFragment-->"
-#   define FRAG_END "<!--EndFragment-->"
-    const auto expected = QByteArrayLiteral(FRAG_START "TEST" FRAG_END "LINE 1");
-#else
     const auto expected = QByteArrayLiteral("TESTLINE 1");
+#ifdef Q_OS_WIN
+    const auto expectedClipboard = QByteArrayLiteral("<!--StartFragment-->TESTLINE 1<!--EndFragment-->", mimeHtml);
+#else
+    const auto expectedClipboard = expected;
 #endif
     RUN("read" << mimeHtml << "0", expected);
     RUN("read" << "0", "");
-    WAIT_FOR_CLIPBOARD2(expected, mimeHtml);
+    WAIT_FOR_CLIPBOARD2(expectedClipboard, mimeHtml);
     WAIT_FOR_CLIPBOARD("");
 
     // Edit existing item.
@@ -705,7 +729,7 @@ void Tests::commandEditItem()
     RUN("keys" << "END" << "ENTER" << ":LINE 2" << "F2", "");
     RUN("read" << mimeHtml << "0", expected + "\nLINE 2");
     RUN("read" << "0", "");
-    WAIT_FOR_CLIPBOARD2(expected, mimeHtml);
+    WAIT_FOR_CLIPBOARD2(expectedClipboard, mimeHtml);
     WAIT_FOR_CLIPBOARD("");
 
     // Edit clipboard (ignore existing data) and new item.
@@ -713,11 +737,7 @@ void Tests::commandEditItem()
     RUN("keys" << "END" << ":LINE 1" << "F2", "");
     RUN("read" << mimeHtml << "0", "TESTLINE 1");
     RUN("read" << "0", "");
-#ifdef Q_OS_WIN
-    WAIT_FOR_CLIPBOARD2(FRAG_START "TESTLINE 1" FRAG_END, mimeHtml);
-#else
-    WAIT_FOR_CLIPBOARD2("TESTLINE 1", mimeHtml);
-#endif
+    WAIT_FOR_CLIPBOARD2(expectedClipboard, mimeHtml);
     WAIT_FOR_CLIPBOARD("");
 }
 
@@ -1102,7 +1122,7 @@ void Tests::commandForceUnload()
 void Tests::commandServerLogAndLogs()
 {
     const QByteArray data1 = generateData();
-    QRegularExpression re("CopyQ Note \\[[^]]+\\] <Server-[0-9]+>: " + QRegularExpression::escape(data1));
+    QRegularExpression re("\\[[^]]+\\] Note <Server-[0-9]+>: " + QRegularExpression::escape(data1));
 
     QByteArray stdoutActual;
     QByteArray stderrActual;
@@ -1117,7 +1137,7 @@ void Tests::commandServerLogAndLogs()
     QCOMPARE( run(Args("logs"), &stdoutActual, &stderrActual), 0 );
     QVERIFY2( testStderr(stderrActual), stderrActual );
     QVERIFY( !stdoutActual.isEmpty() );
-    QVERIFY( QString::fromUtf8(stdoutActual).contains(re) );
+    QVERIFY2( QString::fromUtf8(stdoutActual).contains(re), stdoutActual );
 }
 
 void Tests::chainingCommands()
@@ -1154,3 +1174,10 @@ void Tests::insertRemoveItems()
     QCOMPARE( run(Args(args) << "insert" << "1" << "-", nullptr, nullptr, in), 0);
     RUN(args << "read" << "0" << "1" << "2" << "3" << "4", "abc,ABC,ghi,,");
 }
+
+void Tests::handleUnexpectedTypes()
+{
+    RUN("add(version)", "");
+    RUN("add([version])", "");
+    RUN("add({version: version})", "");
+}
